@@ -468,7 +468,7 @@ process_header (GMimeObject *object, const char *header, const char *value)
 	time_t date;
 	
 	for (i = 0; headers[i]; i++) {
-		if (!g_strcasecmp (headers[i], header))
+		if (!strcasecmp (headers[i], header))
 			break;
 	}
 	
@@ -513,13 +513,13 @@ process_header (GMimeObject *object, const char *header, const char *value)
 static void
 message_add_header (GMimeObject *object, const char *header, const char *value)
 {
-	if (!g_strcasecmp ("MIME-Version", header))
+	if (!strcasecmp ("MIME-Version", header))
 		return;
 	
 	/* Make sure that the header is not a Content-* header, else it
            doesn't belong on a message */
 	
-	if (g_strncasecmp ("Content-", header, 8)) {
+	if (strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_add (object->headers, header, value);
 		else
@@ -530,13 +530,13 @@ message_add_header (GMimeObject *object, const char *header, const char *value)
 static void
 message_set_header (GMimeObject *object, const char *header, const char *value)
 {
-	if (!g_strcasecmp ("MIME-Version", header))
+	if (!strcasecmp ("MIME-Version", header))
 		return;
 	
 	/* Make sure that the header is not a Content-* header, else it
            doesn't belong on a message */
 	
-	if (g_strncasecmp ("Content-", header, 8)) {
+	if (strncasecmp ("Content-", header, 8)) {
 		if (process_header (object, header, value))
 			g_mime_header_set (object->headers, header, value);
 		else
@@ -550,10 +550,10 @@ message_get_header (GMimeObject *object, const char *header)
 	/* Make sure that the header is not a Content-* header, else it
            doesn't belong on a message */
 	
-	if (!g_strcasecmp ("MIME-Version", header))
+	if (!strcasecmp ("MIME-Version", header))
 		return "1.0";
 	
-	if (g_strncasecmp ("Content-", header, 8))
+	if (strncasecmp ("Content-", header, 8))
 		return GMIME_OBJECT_CLASS (parent_class)->get_header (object, header);
 	else
 		return NULL;
@@ -566,17 +566,17 @@ message_remove_header (GMimeObject *object, const char *header)
 	InternetAddressList *addrlist;
 	int i;
 	
-	if (!g_strcasecmp ("MIME-Version", header))
+	if (!strcasecmp ("MIME-Version", header))
 		return;
 	
 	/* Make sure that the header is not a Content-* header, else it
            doesn't belong on a message */
 	
-	if (!g_strncasecmp ("Content-", header, 8))
+	if (!strncasecmp ("Content-", header, 8))
 		return;
 	
 	for (i = 0; headers[i]; i++) {
-		if (!g_strcasecmp (headers[i], header))
+		if (!strcasecmp (headers[i], header))
 			break;
 	}
 	
@@ -806,7 +806,7 @@ g_mime_message_get_reply_to (GMimeMessage *message)
 static void
 sync_recipient_header (GMimeMessage *message, const char *type)
 {
-	InternetAddressList *recipients;
+	const InternetAddressList *recipients;
 	
 	/* sync the specified recipient header */
 	recipients = g_mime_message_get_recipients (message, type);
@@ -911,7 +911,7 @@ g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, co
  * Returns a list of recipients of a chosen type from the MIME
  * Message.
  **/
-InternetAddressList *
+const InternetAddressList *
 g_mime_message_get_recipients (GMimeMessage *message, const char *type)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE (message), NULL);
@@ -948,7 +948,7 @@ g_mime_message_set_subject (GMimeMessage *message, const char *subject)
 	
 	message_set_subject (message, subject);
 	
-	encoded = g_mime_utils_8bit_header_encode (message->subject);
+	encoded = g_mime_utils_header_encode_text (message->subject);
 	g_mime_header_set (GMIME_OBJECT (message)->headers, "Subject", encoded);
 	g_free (encoded);
 }
@@ -1225,8 +1225,8 @@ handle_multipart_alternative (GMimeMultipart *multipart, gboolean want_plain, gb
 		
 		type = g_mime_object_get_content_type (mime_part);
 		if (g_mime_content_type_is_type (type, "text", "*")) {
-			if (!text_part || !g_strcasecmp (type->subtype, want_plain ? "plain" : "html")) {
-				*is_html = !g_strcasecmp (type->subtype, "html");
+			if (!text_part || !strcasecmp (type->subtype, want_plain ? "plain" : "html")) {
+				*is_html = !strcasecmp (type->subtype, "html");
 				text_part = mime_part;
 			}
 		}
@@ -1261,7 +1261,7 @@ handle_multipart_mixed (GMimeMultipart *multipart, gboolean want_plain, gboolean
 					text_part = mime_part;
 			}
 		} else if (g_mime_content_type_is_type (type, "text", "*")) {
-			if (!g_strcasecmp (type->subtype, want_plain ? "plain" : "html")) {
+			if (!strcasecmp (type->subtype, want_plain ? "plain" : "html")) {
 				/* we got what we came for */
 				*is_html = !want_plain;
 				return mime_part;
@@ -1270,9 +1270,9 @@ handle_multipart_mixed (GMimeMultipart *multipart, gboolean want_plain, gboolean
 			/* if we haven't yet found a text part or if
                            it is a type we can understand and it is
                            the first of that type, save it */
-			if (!text_part || (!g_strcasecmp (type->subtype, "plain") && (first_type &&
-					   g_strcasecmp (type->subtype, first_type->subtype) != 0))) {
-				*is_html = !g_strcasecmp (type->subtype, "html");
+			if (!text_part || (!strcasecmp (type->subtype, "plain") && (first_type &&
+					   strcasecmp (type->subtype, first_type->subtype) != 0))) {
+				*is_html = !strcasecmp (type->subtype, "html");
 				text_part = mime_part;
 				first_type = type;
 			}
